<?php

return [
    'Names' => [
        'af' => 'අෆ්‍රිකාන්ස්',
        'af_NA' => 'අෆ්‍රිකාන්ස් (නැමීබියාව)',
        'af_ZA' => 'අෆ්‍රිකාන්ස් (දකුණු අප්‍රිකාව)',
        'ak' => 'අකාන්',
        'ak_GH' => 'අකාන් (ඝානාව)',
        'am' => 'ඇම්හාරික්',
        'am_ET' => 'ඇම්හාරික් (ඉතියෝපියාව)',
        'ar' => 'අරාබි',
        'ar_001' => 'අරාබි (ලෝකය)',
        'ar_AE' => 'අරාබි (එක්සත් අරාබි එමිර් රාජ්‍යය)',
        'ar_BH' => 'අරාබි (බහරේන්)',
        'ar_DJ' => 'අරාබි (ජිබුටි)',
        'ar_DZ' => 'අරාබි (ඇල්ජීරියාව)',
        'ar_EG' => 'අරාබි (ඊජිප්තුව)',
        'ar_EH' => 'අරාබි (බටහිර සහරාව)',
        'ar_ER' => 'අරාබි (එරිත්‍රියාව)',
        'ar_IL' => 'අරාබි (ඊශ්‍රායලය)',
        'ar_IQ' => 'අරාබි (ඉරාකය)',
        'ar_JO' => 'අරාබි (ජෝර්දානය)',
        'ar_KM' => 'අරාබි (කොමොරෝස්)',
        'ar_KW' => 'අරාබි (කුවේටය)',
        'ar_LB' => 'අරාබි (ලෙබනනය)',
        'ar_LY' => 'අරාබි (ලිබියාව)',
        'ar_MA' => 'අරාබි (මොරොක්කෝව)',
        'ar_MR' => 'අරාබි (මොරිටේනියාව)',
        'ar_OM' => 'අරාබි (ඕමානය)',
        'ar_PS' => 'අරාබි (පලස්තීන රාජ්‍යය)',
        'ar_QA' => 'අරාබි (කටාර්)',
        'ar_SA' => 'අරාබි (සෞදි අරාබිය)',
        'ar_SD' => 'අරාබි (සූඩානය)',
        'ar_SO' => 'අරාබි (සෝමාලියාව)',
        'ar_SS' => 'අරාබි (දකුණු සුඩානය)',
        'ar_SY' => 'අරාබි (සිරියාව)',
        'ar_TD' => 'අරාබි (චැච්)',
        'ar_TN' => 'අරාබි (ටියුනීසියාව)',
        'ar_YE' => 'අරාබි (යේමනය)',
        'as' => 'ඇසෑම්',
        'as_IN' => 'ඇසෑම් (ඉන්දියාව)',
        'az' => 'අසර්බයිජාන්',
        'az_AZ' => 'අසර්බයිජාන් (අසර්බයිජානය)',
        'az_Cyrl' => 'අසර්බයිජාන් (සිරිලික්)',
        'az_Cyrl_AZ' => 'අසර්බයිජාන් (සිරිලික්, අසර්බයිජානය)',
        'az_Latn' => 'අසර්බයිජාන් (ලතින්)',
        'az_Latn_AZ' => 'අසර්බයිජාන් (ලතින්, අසර්බයිජානය)',
        'be' => 'බෙලරුසියානු',
        'be_BY' => 'බෙලරුසියානු (බෙලරුස්)',
        'bg' => 'බල්ගේරියානු',
        'bg_BG' => 'බල්ගේරියානු (බල්ගේරියාව)',
        'bm' => 'බම්බරා',
        'bm_ML' => 'බම්බරා (මාලි)',
        'bn' => 'බෙංගාලි',
        'bn_BD' => 'බෙංගාලි (බංග්ලාදේශය)',
        'bn_IN' => 'බෙංගාලි (ඉන්දියාව)',
        'bo' => 'ටිබෙට්',
        'bo_CN' => 'ටිබෙට් (චීනය)',
        'bo_IN' => 'ටිබෙට් (ඉන්දියාව)',
        'br' => 'බ්‍රේටොන්',
        'br_FR' => 'බ්‍රේටොන් (ප්‍රංශය)',
        'bs' => 'බොස්නියානු',
        'bs_BA' => 'බොස්නියානු (බොස්නියාව සහ හර්සගොවීනාව)',
        'bs_Cyrl' => 'බොස්නියානු (සිරිලික්)',
        'bs_Cyrl_BA' => 'බොස්නියානු (සිරිලික්, බොස්නියාව සහ හර්සගොවීනාව)',
        'bs_Latn' => 'බොස්නියානු (ලතින්)',
        'bs_Latn_BA' => 'බොස්නියානු (ලතින්, බොස්නියාව සහ හර්සගොවීනාව)',
        'ca' => 'කැටලන්',
        'ca_AD' => 'කැටලන් (ඇන්ඩෝරාව)',
        'ca_ES' => 'කැටලන් (ස්පාඤ්ඤය)',
        'ca_FR' => 'කැටලන් (ප්‍රංශය)',
        'ca_IT' => 'කැටලන් (ඉතාලිය)',
        'ce' => 'චෙච්නියානු',
        'ce_RU' => 'චෙච්නියානු (රුසියාව)',
        'cs' => 'චෙක්',
        'cs_CZ' => 'චෙක් (චෙචියාව)',
        'cv' => 'චවේෂ්',
        'cv_RU' => 'චවේෂ් (රුසියාව)',
        'cy' => 'වෙල්ෂ්',
        'cy_GB' => 'වෙල්ෂ් (එක්සත් රාජධානිය)',
        'da' => 'ඩැනිශ්',
        'da_DK' => 'ඩැනිශ් (ඩෙන්මාර්කය)',
        'da_GL' => 'ඩැනිශ් (ග්‍රීන්ලන්තය)',
        'de' => 'ජර්මන්',
        'de_AT' => 'ජර්මන් (ඔස්ට්‍රියාව)',
        'de_BE' => 'ජර්මන් (බෙල්ජියම)',
        'de_CH' => 'ජර්මන් (ස්විස්ටර්ලන්තය)',
        'de_DE' => 'ජර්මන් (ජර්මනිය)',
        'de_IT' => 'ජර්මන් (ඉතාලිය)',
        'de_LI' => 'ජර්මන් (ලික්ටන්ස්ටයින්)',
        'de_LU' => 'ජර්මන් (ලක්ශම්බර්ග්)',
        'dz' => 'ඩිසොන්කා',
        'dz_BT' => 'ඩිසොන්කා (භූතානය)',
        'ee' => 'ඉව්',
        'ee_GH' => 'ඉව් (ඝානාව)',
        'ee_TG' => 'ඉව් (ටොගෝ)',
        'el' => 'ග්‍රීක',
        'el_CY' => 'ග්‍රීක (සයිප්‍රසය)',
        'el_GR' => 'ග්‍රීක (ග්‍රීසිය)',
        'en' => 'ඉංග්‍රීසි',
        'en_001' => 'ඉංග්‍රීසි (ලෝකය)',
        'en_150' => 'ඉංග්‍රීසි (යුරෝපය)',
        'en_AE' => 'ඉංග්‍රීසි (එක්සත් අරාබි එමිර් රාජ්‍යය)',
        'en_AG' => 'ඉංග්‍රීසි (ඇන්ටිගුවා සහ බාබියුඩාව)',
        'en_AI' => 'ඉංග්‍රීසි (ඇන්ගුයිලාව)',
        'en_AS' => 'ඉංග්‍රීසි (ඇමරිකානු සැමෝවා)',
        'en_AT' => 'ඉංග්‍රීසි (ඔස්ට්‍රියාව)',
        'en_AU' => 'ඉංග්‍රීසි (ඕස්ට්‍රේලියාව)',
        'en_BB' => 'ඉංග්‍රීසි (බාබඩෝස්)',
        'en_BE' => 'ඉංග්‍රීසි (බෙල්ජියම)',
        'en_BI' => 'ඉංග්‍රීසි (බුරුන්දි)',
        'en_BM' => 'ඉංග්‍රීසි (බර්මියුඩා)',
        'en_BS' => 'ඉංග්‍රීසි (බහමාස්)',
        'en_BW' => 'ඉංග්‍රීසි (බොට්ස්වානා)',
        'en_BZ' => 'ඉංග්‍රීසි (බෙලීස්)',
        'en_CA' => 'ඉංග්‍රීසි (කැනඩාව)',
        'en_CC' => 'ඉංග්‍රීසි (කොකෝස් දූපත්)',
        'en_CH' => 'ඉංග්‍රීසි (ස්විස්ටර්ලන්තය)',
        'en_CK' => 'ඉංග්‍රීසි (කුක් දූපත්)',
        'en_CM' => 'ඉංග්‍රීසි (කැමරූන්)',
        'en_CX' => 'ඉංග්‍රීසි (ක්‍රිස්මස් දූපත)',
        'en_CY' => 'ඉංග්‍රීසි (සයිප්‍රසය)',
        'en_DE' => 'ඉංග්‍රීසි (ජර්මනිය)',
        'en_DK' => 'ඉංග්‍රීසි (ඩෙන්මාර්කය)',
        'en_DM' => 'ඉංග්‍රීසි (ඩොමිනිකාව)',
        'en_ER' => 'ඉංග්‍රීසි (එරිත්‍රියාව)',
        'en_FI' => 'ඉංග්‍රීසි (ෆින්ලන්තය)',
        'en_FJ' => 'ඉංග්‍රීසි (ෆීජී)',
        'en_FK' => 'ඉංග්‍රීසි (ෆෝක්ලන්ත දූපත්)',
        'en_FM' => 'ඉංග්‍රීසි (මයික්‍රොනීසියාව)',
        'en_GB' => 'ඉංග්‍රීසි (එක්සත් රාජධානිය)',
        'en_GD' => 'ඉංග්‍රීසි (ග්‍රැනඩාව)',
        'en_GG' => 'ඉංග්‍රීසි (ගර්න්සිය)',
        'en_GH' => 'ඉංග්‍රීසි (ඝානාව)',
        'en_GI' => 'ඉංග්‍රීසි (ජිබ්‍රෝල්ටාව)',
        'en_GM' => 'ඉංග්‍රීසි (ගැම්බියාව)',
        'en_GU' => 'ඉංග්‍රීසි (ගුවාම්)',
        'en_GY' => 'ඉංග්‍රීසි (ගයනාව)',
        'en_HK' => 'ඉංග්‍රීසි (හොංකොං විශේෂ පරිපාලන කලාපය චීනය)',
        'en_IE' => 'ඉංග්‍රීසි (අයර්ලන්තය)',
        'en_IL' => 'ඉංග්‍රීසි (ඊශ්‍රායලය)',
        'en_IM' => 'ඉංග්‍රීසි (අයිල් ඔෆ් මෑන්)',
        'en_IN' => 'ඉංග්‍රීසි (ඉන්දියාව)',
        'en_IO' => 'ඉංග්‍රීසි (බ්‍රිතාන්‍ය ඉන්දීය සාගර බල ප්‍රදේශය)',
        'en_JE' => 'ඉංග්‍රීසි (ජර්සි)',
        'en_JM' => 'ඉංග්‍රීසි (ජැමෙයිකාව)',
        'en_KE' => 'ඉංග්‍රීසි (කෙන්යාව)',
        'en_KI' => 'ඉංග්‍රීසි (කිරිබති)',
        'en_KN' => 'ඉංග්‍රීසි (ශාන්ත කිට්ස් සහ නේවිස්)',
        'en_KY' => 'ඉංග්‍රීසි (කේමන් දූපත්)',
        'en_LC' => 'ඉංග්‍රීසි (ශාන්ත ලුසියා)',
        'en_LR' => 'ඉංග්‍රීසි (ලයිබීරියාව)',
        'en_LS' => 'ඉංග්‍රීසි (ලෙසතෝ)',
        'en_MG' => 'ඉංග්‍රීසි (මැඩගස්කරය)',
        'en_MH' => 'ඉංග්‍රීසි (මාෂල් දූපත්)',
        'en_MO' => 'ඉංග්‍රීසි (මැකාවු විශේෂ පරිපාලන කලාපය චීනය)',
        'en_MP' => 'ඉංග්‍රීසි (උතුරු මරියානා දූපත්)',
        'en_MS' => 'ඉංග්‍රීසි (මොන්සෙරාට්)',
        'en_MT' => 'ඉංග්‍රීසි (මෝල්ටාව)',
        'en_MU' => 'ඉංග්‍රීසි (මුරුසිය)',
        'en_MV' => 'ඉංග්‍රීසි (මාල දිවයින)',
        'en_MW' => 'ඉංග්‍රීසි (මලාවි)',
        'en_MY' => 'ඉංග්‍රීසි (මැලේසියාව)',
        'en_NA' => 'ඉංග්‍රීසි (නැමීබියාව)',
        'en_NF' => 'ඉංග්‍රීසි (නෝෆෝක් දූපත)',
        'en_NG' => 'ඉංග්‍රීසි (නයිජීරියාව)',
        'en_NL' => 'ඉංග්‍රීසි (නෙදර්ලන්තය)',
        'en_NR' => 'ඉංග්‍රීසි (නාවුරු)',
        'en_NU' => 'ඉංග්‍රීසි (නියූ)',
        'en_NZ' => 'ඉංග්‍රීසි (නවසීලන්තය)',
        'en_PG' => 'ඉංග්‍රීසි (පැපුවා නිව් ගිනියාව)',
        'en_PH' => 'ඉංග්‍රීසි (පිලිපීනය)',
        'en_PK' => 'ඉංග්‍රීසි (පාකිස්තානය)',
        'en_PN' => 'ඉංග්‍රීසි (පිට්කෙය්න් දූපත්)',
        'en_PR' => 'ඉංග්‍රීසි (පුවර්ටෝ රිකෝ)',
        'en_PW' => 'ඉංග්‍රීසි (පලාවු)',
        'en_RW' => 'ඉංග්‍රීසි (රුවන්ඩාව)',
        'en_SB' => 'ඉංග්‍රීසි (සොලමන් දූපත්)',
        'en_SC' => 'ඉංග්‍රීසි (සීශෙල්ස්)',
        'en_SD' => 'ඉංග්‍රීසි (සූඩානය)',
        'en_SE' => 'ඉංග්‍රීසි (ස්වීඩනය)',
        'en_SG' => 'ඉංග්‍රීසි (සිංගප්පූරුව)',
        'en_SH' => 'ඉංග්‍රීසි (ශාන්ත හෙලේනා)',
        'en_SI' => 'ඉංග්‍රීසි (ස්ලෝවේනියාව)',
        'en_SL' => 'ඉංග්‍රීසි (සියරාලියෝන්)',
        'en_SS' => 'ඉංග්‍රීසි (දකුණු සුඩානය)',
        'en_SX' => 'ඉංග්‍රීසි (ශාන්ත මාර්ටෙන්)',
        'en_SZ' => 'ඉංග්‍රීසි (එස්වාටිනි)',
        'en_TC' => 'ඉංග්‍රීසි (ටර්ක්ස් සහ කයිකොස් දූපත්)',
        'en_TK' => 'ඉංග්‍රීසි (ටොකලාවු)',
        'en_TO' => 'ඉංග්‍රීසි (ටොංගා)',
        'en_TT' => 'ඉංග්‍රීසි (ට්‍රිනිඩෑඩ් සහ ටොබැගෝ)',
        'en_TV' => 'ඉංග්‍රීසි (ටුවාලූ)',
        'en_TZ' => 'ඉංග්‍රීසි (ටැන්සානියාව)',
        'en_UG' => 'ඉංග්‍රීසි (උගන්ඩාව)',
        'en_UM' => 'ඉංග්‍රීසි (එක්සත් ජනපද ඈත දූපත්)',
        'en_US' => 'ඉංග්‍රීසි (එක්සත් ජනපදය)',
        'en_VC' => 'ඉංග්‍රීසි (ශාන්ත වින්සන්ට් සහ ග්‍රෙනඩින්ස්)',
        'en_VG' => 'ඉංග්‍රීසි (බ්‍රිතාන්‍ය වර්ජින් දූපත්)',
        'en_VI' => 'ඉංග්‍රීසි (ඇමරිකානු වර්ජින් දූපත්)',
        'en_VU' => 'ඉංග්‍රීසි (වනුවාටු)',
        'en_WS' => 'ඉංග්‍රීසි (සැමෝවා)',
        'en_ZA' => 'ඉංග්‍රීසි (දකුණු අප්‍රිකාව)',
        'en_ZM' => 'ඉංග්‍රීසි (සැම්බියාව)',
        'en_ZW' => 'ඉංග්‍රීසි (සිම්බාබ්වේ)',
        'eo' => 'එස්පැරන්ටෝ',
        'eo_001' => 'එස්පැරන්ටෝ (ලෝකය)',
        'es' => 'ස්පාඤ්ඤ',
        'es_419' => 'ස්පාඤ්ඤ (ලතින් ඇමෙරිකාව)',
        'es_AR' => 'ස්පාඤ්ඤ (ආර්ජෙන්ටිනාව)',
        'es_BO' => 'ස්පාඤ්ඤ (බොලීවියාව)',
        'es_BR' => 'ස්පාඤ්ඤ (බ්‍රසීලය)',
        'es_BZ' => 'ස්පාඤ්ඤ (බෙලීස්)',
        'es_CL' => 'ස්පාඤ්ඤ (චිලී)',
        'es_CO' => 'ස්පාඤ්ඤ (කොළොම්බියාව)',
        'es_CR' => 'ස්පාඤ්ඤ (කොස්ටරිකාව)',
        'es_CU' => 'ස්පාඤ්ඤ (කියුබාව)',
        'es_DO' => 'ස්පාඤ්ඤ (ඩොමිනිකා ජනරජය)',
        'es_EC' => 'ස්පාඤ්ඤ (ඉක්වදෝරය)',
        'es_ES' => 'ස්පාඤ්ඤ (ස්පාඤ්ඤය)',
        'es_GQ' => 'ස්පාඤ්ඤ (සමක ගිනියාව)',
        'es_GT' => 'ස්පාඤ්ඤ (ගෝතමාලාව)',
        'es_HN' => 'ස්පාඤ්ඤ (හොන්ඩුරාස්)',
        'es_MX' => 'ස්පාඤ්ඤ (මෙක්සිකෝව)',
        'es_NI' => 'ස්පාඤ්ඤ (නිකරගුවාව)',
        'es_PA' => 'ස්පාඤ්ඤ (පැනමාව)',
        'es_PE' => 'ස්පාඤ්ඤ (පේරු)',
        'es_PH' => 'ස්පාඤ්ඤ (පිලිපීනය)',
        'es_PR' => 'ස්පාඤ්ඤ (පුවර්ටෝ රිකෝ)',
        'es_PY' => 'ස්පාඤ්ඤ (පැරගුවේ)',
        'es_SV' => 'ස්පාඤ්ඤ (එල් සැල්වදෝරය)',
        'es_US' => 'ස්පාඤ්ඤ (එක්සත් ජනපදය)',
        'es_UY' => 'ස්පාඤ්ඤ (උරුගුවේ)',
        'es_VE' => 'ස්පාඤ්ඤ (වෙනිසියුලාව)',
        'et' => 'එස්තෝනියානු',
        'et_EE' => 'එස්තෝනියානු (එස්තෝනියාව)',
        'eu' => 'බාස්ක්',
        'eu_ES' => 'බාස්ක් (ස්පාඤ්ඤය)',
        'fa' => 'පර්සියානු',
        'fa_AF' => 'පර්සියානු (ඇෆ්ගනිස්ථානය)',
        'fa_IR' => 'පර්සියානු (ඉරානය)',
        'ff' => 'ෆුලාහ්',
        'ff_Adlm' => 'ෆුලාහ් (ඇඩ්ලම්)',
        'ff_Adlm_BF' => 'ෆුලාහ් (ඇඩ්ලම්, බර්කිනා ෆාසෝ)',
        'ff_Adlm_CM' => 'ෆුලාහ් (ඇඩ්ලම්, කැමරූන්)',
        'ff_Adlm_GH' => 'ෆුලාහ් (ඇඩ්ලම්, ඝානාව)',
        'ff_Adlm_GM' => 'ෆුලාහ් (ඇඩ්ලම්, ගැම්බියාව)',
        'ff_Adlm_GN' => 'ෆුලාහ් (ඇඩ්ලම්, ගිණියාව)',
        'ff_Adlm_GW' => 'ෆුලාහ් (ඇඩ්ලම්, ගිනි බිසව්)',
        'ff_Adlm_LR' => 'ෆුලාහ් (ඇඩ්ලම්, ලයිබීරියාව)',
        'ff_Adlm_MR' => 'ෆුලාහ් (ඇඩ්ලම්, මොරිටේනියාව)',
        'ff_Adlm_NE' => 'ෆුලාහ් (ඇඩ්ලම්, නයිජර්)',
        'ff_Adlm_NG' => 'ෆුලාහ් (ඇඩ්ලම්, නයිජීරියාව)',
        'ff_Adlm_SL' => 'ෆුලාහ් (ඇඩ්ලම්, සියරාලියෝන්)',
        'ff_Adlm_SN' => 'ෆුලාහ් (ඇඩ්ලම්, සෙනගාලය)',
        'ff_CM' => 'ෆුලාහ් (කැමරූන්)',
        'ff_GN' => 'ෆුලාහ් (ගිණියාව)',
        'ff_Latn' => 'ෆුලාහ් (ලතින්)',
        'ff_Latn_BF' => 'ෆුලාහ් (ලතින්, බර්කිනා ෆාසෝ)',
        'ff_Latn_CM' => 'ෆුලාහ් (ලතින්, කැමරූන්)',
        'ff_Latn_GH' => 'ෆුලාහ් (ලතින්, ඝානාව)',
        'ff_Latn_GM' => 'ෆුලාහ් (ලතින්, ගැම්බියාව)',
        'ff_Latn_GN' => 'ෆුලාහ් (ලතින්, ගිණියාව)',
        'ff_Latn_GW' => 'ෆුලාහ් (ලතින්, ගිනි බිසව්)',
        'ff_Latn_LR' => 'ෆුලාහ් (ලතින්, ලයිබීරියාව)',
        'ff_Latn_MR' => 'ෆුලාහ් (ලතින්, මොරිටේනියාව)',
        'ff_Latn_NE' => 'ෆුලාහ් (ලතින්, නයිජර්)',
        'ff_Latn_NG' => 'ෆුලාහ් (ලතින්, නයිජීරියාව)',
        'ff_Latn_SL' => 'ෆුලාහ් (ලතින්, සියරාලියෝන්)',
        'ff_Latn_SN' => 'ෆුලාහ් (ලතින්, සෙනගාලය)',
        'ff_MR' => 'ෆුලාහ් (මොරිටේනියාව)',
        'ff_SN' => 'ෆුලාහ් (සෙනගාලය)',
        'fi' => 'ෆින්ලන්ත',
        'fi_FI' => 'ෆින්ලන්ත (ෆින්ලන්තය)',
        'fo' => 'ෆාරෝස්',
        'fo_DK' => 'ෆාරෝස් (ඩෙන්මාර්කය)',
        'fo_FO' => 'ෆාරෝස් (ෆැරෝ දූපත්)',
        'fr' => 'ප්‍රංශ',
        'fr_BE' => 'ප්‍රංශ (බෙල්ජියම)',
        'fr_BF' => 'ප්‍රංශ (බර්කිනා ෆාසෝ)',
        'fr_BI' => 'ප්‍රංශ (බුරුන්දි)',
        'fr_BJ' => 'ප්‍රංශ (බෙනින්)',
        'fr_BL' => 'ප්‍රංශ (ශාන්ත බර්තලෙමි)',
        'fr_CA' => 'ප්‍රංශ (කැනඩාව)',
        'fr_CD' => 'ප්‍රංශ (කොංගෝව [ඩීආර්සී])',
        'fr_CF' => 'ප්‍රංශ (මධ්‍යම අප්‍රිකානු ජනරජය)',
        'fr_CG' => 'ප්‍රංශ (කොංගො - බ්‍රසාවිල්)',
        'fr_CH' => 'ප්‍රංශ (ස්විස්ටර්ලන්තය)',
        'fr_CI' => 'ප්‍රංශ (කෝට් දි අයිවරි)',
        'fr_CM' => 'ප්‍රංශ (කැමරූන්)',
        'fr_DJ' => 'ප්‍රංශ (ජිබුටි)',
        'fr_DZ' => 'ප්‍රංශ (ඇල්ජීරියාව)',
        'fr_FR' => 'ප්‍රංශ (ප්‍රංශය)',
        'fr_GA' => 'ප්‍රංශ (ගැබොන්)',
        'fr_GF' => 'ප්‍රංශ (ප්‍රංශ ගයනාව)',
        'fr_GN' => 'ප්‍රංශ (ගිණියාව)',
        'fr_GP' => 'ප්‍රංශ (ග්වෝඩලෝප්)',
        'fr_GQ' => 'ප්‍රංශ (සමක ගිනියාව)',
        'fr_HT' => 'ප්‍රංශ (හයිටි)',
        'fr_KM' => 'ප්‍රංශ (කොමොරෝස්)',
        'fr_LU' => 'ප්‍රංශ (ලක්ශම්බර්ග්)',
        'fr_MA' => 'ප්‍රංශ (මොරොක්කෝව)',
        'fr_MC' => 'ප්‍රංශ (මොනාකෝව)',
        'fr_MF' => 'ප්‍රංශ (ශාන්ත මාර්ටින්)',
        'fr_MG' => 'ප්‍රංශ (මැඩගස්කරය)',
        'fr_ML' => 'ප්‍රංශ (මාලි)',
        'fr_MQ' => 'ප්‍රංශ (මර්ටිනික්)',
        'fr_MR' => 'ප්‍රංශ (මොරිටේනියාව)',
        'fr_MU' => 'ප්‍රංශ (මුරුසිය)',
        'fr_NC' => 'ප්‍රංශ (නව කැලිඩෝනියාව)',
        'fr_NE' => 'ප්‍රංශ (නයිජර්)',
        'fr_PF' => 'ප්‍රංශ (ප්‍රංශ පොලිනීසියාව)',
        'fr_PM' => 'ප්‍රංශ (ශාන්ත පියරේ සහ මැකෝලන්)',
        'fr_RE' => 'ප්‍රංශ (රීයුනියන්)',
        'fr_RW' => 'ප්‍රංශ (රුවන්ඩාව)',
        'fr_SC' => 'ප්‍රංශ (සීශෙල්ස්)',
        'fr_SN' => 'ප්‍රංශ (සෙනගාලය)',
        'fr_SY' => 'ප්‍රංශ (සිරියාව)',
        'fr_TD' => 'ප්‍රංශ (චැච්)',
        'fr_TG' => 'ප්‍රංශ (ටොගෝ)',
        'fr_TN' => 'ප්‍රංශ (ටියුනීසියාව)',
        'fr_VU' => 'ප්‍රංශ (වනුවාටු)',
        'fr_WF' => 'ප්‍රංශ (වැලිස් සහ ෆුටුනා)',
        'fr_YT' => 'ප්‍රංශ (මයෝට්)',
        'fy' => 'බටහිර ෆ්‍රිසියානු',
        'fy_NL' => 'බටහිර ෆ්‍රිසියානු (නෙදර්ලන්තය)',
        'ga' => 'අයර්ලන්ත',
        'ga_GB' => 'අයර්ලන්ත (එක්සත් රාජධානිය)',
        'ga_IE' => 'අයර්ලන්ත (අයර්ලන්තය)',
        'gd' => 'ස්කොට්ටිශ් ගෙලික්',
        'gd_GB' => 'ස්කොට්ටිශ් ගෙලික් (එක්සත් රාජධානිය)',
        'gl' => 'ගැලීසියානු',
        'gl_ES' => 'ගැලීසියානු (ස්පාඤ්ඤය)',
        'gu' => 'ගුජරාටි',
        'gu_IN' => 'ගුජරාටි (ඉන්දියාව)',
        'gv' => 'මැන්ක්ස්',
        'gv_IM' => 'මැන්ක්ස් (අයිල් ඔෆ් මෑන්)',
        'ha' => 'හෝසා',
        'ha_GH' => 'හෝසා (ඝානාව)',
        'ha_NE' => 'හෝසා (නයිජර්)',
        'ha_NG' => 'හෝසා (නයිජීරියාව)',
        'he' => 'හීබෲ',
        'he_IL' => 'හීබෲ (ඊශ්‍රායලය)',
        'hi' => 'හින්දි',
        'hi_IN' => 'හින්දි (ඉන්දියාව)',
        'hi_Latn' => 'හින්දි (ලතින්)',
        'hi_Latn_IN' => 'හින්දි (ලතින්, ඉන්දියාව)',
        'hr' => 'කෝඒෂියානු',
        'hr_BA' => 'කෝඒෂියානු (බොස්නියාව සහ හර්සගොවීනාව)',
        'hr_HR' => 'කෝඒෂියානු (ක්‍රොඒෂියාව)',
        'hu' => 'හන්ගේරියානු',
        'hu_HU' => 'හන්ගේරියානු (හන්ගේරියාව)',
        'hy' => 'ආර්මේනියානු',
        'hy_AM' => 'ආර්මේනියානු (ආර්මේනියාව)',
        'ia' => 'ඉන්ටලින්ගුආ',
        'ia_001' => 'ඉන්ටලින්ගුආ (ලෝකය)',
        'id' => 'ඉන්දුනීසියානු',
        'id_ID' => 'ඉන්දුනීසියානු (ඉන්දුනීසියාව)',
        'ig' => 'ඉග්බෝ',
        'ig_NG' => 'ඉග්බෝ (නයිජීරියාව)',
        'ii' => 'සිචුආන් යී',
        'ii_CN' => 'සිචුආන් යී (චීනය)',
        'is' => 'අයිස්ලන්ත',
        'is_IS' => 'අයිස්ලන්ත (අයිස්ලන්තය)',
        'it' => 'ඉතාලි',
        'it_CH' => 'ඉතාලි (ස්විස්ටර්ලන්තය)',
        'it_IT' => 'ඉතාලි (ඉතාලිය)',
        'it_SM' => 'ඉතාලි (සැන් මැරිනෝ)',
        'it_VA' => 'ඉතාලි (වතිකානු නගරය)',
        'ja' => 'ජපන්',
        'ja_JP' => 'ජපන් (ජපානය)',
        'jv' => 'ජාවා',
        'jv_ID' => 'ජාවා (ඉන්දුනීසියාව)',
        'ka' => 'ජෝර්ජියානු',
        'ka_GE' => 'ජෝර්ජියානු (ජෝර්ජියාව)',
        'ki' => 'කිකුයු',
        'ki_KE' => 'කිකුයු (කෙන්යාව)',
        'kk' => 'කසාඛ්',
        'kk_KZ' => 'කසාඛ් (කසකස්තානය)',
        'kl' => 'කලාලිසට්',
        'kl_GL' => 'කලාලිසට් (ග්‍රීන්ලන්තය)',
        'km' => 'කමර්',
        'km_KH' => 'කමර් (කාම්බෝජය)',
        'kn' => 'කණ්ණඩ',
        'kn_IN' => 'කණ්ණඩ (ඉන්දියාව)',
        'ko' => 'කොරියානු',
        'ko_KP' => 'කොරියානු (උතුරු කොරියාව)',
        'ko_KR' => 'කොරියානු (දකුණු කොරියාව)',
        'ks' => 'කාෂ්මීර්',
        'ks_Arab' => 'කාෂ්මීර් (අරාබි)',
        'ks_Arab_IN' => 'කාෂ්මීර් (අරාබි, ඉන්දියාව)',
        'ks_Deva' => 'කාෂ්මීර් (දේවනාගරී)',
        'ks_Deva_IN' => 'කාෂ්මීර් (දේවනාගරී, ඉන්දියාව)',
        'ks_IN' => 'කාෂ්මීර් (ඉන්දියාව)',
        'ku' => 'කුර්දි',
        'ku_TR' => 'කුර්දි (තුර්කිය)',
        'kw' => 'කෝනීසියානු',
        'kw_GB' => 'කෝනීසියානු (එක්සත් රාජධානිය)',
        'ky' => 'කිර්ගිස්',
        'ky_KG' => 'කිර්ගිස් (කිර්ගිස්තානය)',
        'lb' => 'ලක්සැම්බර්ග්',
        'lb_LU' => 'ලක්සැම්බර්ග් (ලක්ශම්බර්ග්)',
        'lg' => 'ගන්ඩා',
        'lg_UG' => 'ගන්ඩා (උගන්ඩාව)',
        'ln' => 'ලින්ගලා',
        'ln_AO' => 'ලින්ගලා (ඇන්ගෝලාව)',
        'ln_CD' => 'ලින්ගලා (කොංගෝව [ඩීආර්සී])',
        'ln_CF' => 'ලින්ගලා (මධ්‍යම අප්‍රිකානු ජනරජය)',
        'ln_CG' => 'ලින්ගලා (කොංගො - බ්‍රසාවිල්)',
        'lo' => 'ලාඕ',
        'lo_LA' => 'ලාඕ (ලාඕසය)',
        'lt' => 'ලිතුවේනියානු',
        'lt_LT' => 'ලිතුවේනියානු (ලිතුවේනියාව)',
        'lu' => 'ලුබා-කටන්ගා',
        'lu_CD' => 'ලුබා-කටන්ගා (කොංගෝව [ඩීආර්සී])',
        'lv' => 'ලැට්වියානු',
        'lv_LV' => 'ලැට්වියානු (ලැට්වියාව)',
        'mg' => 'මලගාසි',
        'mg_MG' => 'මලගාසි (මැඩගස්කරය)',
        'mi' => 'මාවොරි',
        'mi_NZ' => 'මාවොරි (නවසීලන්තය)',
        'mk' => 'මැසිඩෝනියානු',
        'mk_MK' => 'මැසිඩෝනියානු (උතුරු මැසිඩෝනියාව)',
        'ml' => 'මලයාලම්',
        'ml_IN' => 'මලයාලම් (ඉන්දියාව)',
        'mn' => 'මොංගෝලියානු',
        'mn_MN' => 'මොංගෝලියානු (මොන්ගෝලියාව)',
        'mr' => 'මරාති',
        'mr_IN' => 'මරාති (ඉන්දියාව)',
        'ms' => 'මැලේ',
        'ms_BN' => 'මැලේ (බෲනායි)',
        'ms_ID' => 'මැලේ (ඉන්දුනීසියාව)',
        'ms_MY' => 'මැලේ (මැලේසියාව)',
        'ms_SG' => 'මැලේ (සිංගප්පූරුව)',
        'mt' => 'මොල්ටිස්',
        'mt_MT' => 'මොල්ටිස් (මෝල්ටාව)',
        'my' => 'බුරුම',
        'my_MM' => 'බුරුම (මියන්මාරය [බුරුමය])',
        'nb' => 'නෝර්වීජියානු බොක්මල්',
        'nb_NO' => 'නෝර්වීජියානු බොක්මල් (නෝර්වේ)',
        'nb_SJ' => 'නෝර්වීජියානු බොක්මල් (ස්වෙල්බර්ඩ් සහ ජේන් මයේන්)',
        'nd' => 'උතුරු එන්ඩිබෙලෙ',
        'nd_ZW' => 'උතුරු එන්ඩිබෙලෙ (සිම්බාබ්වේ)',
        'ne' => 'නේපාල',
        'ne_IN' => 'නේපාල (ඉන්දියාව)',
        'ne_NP' => 'නේපාල (නේපාලය)',
        'nl' => 'ලන්දේසි',
        'nl_AW' => 'ලන්දේසි (අරූබා)',
        'nl_BE' => 'ලන්දේසි (බෙල්ජියම)',
        'nl_BQ' => 'ලන්දේසි (කැරිබියානු නෙදර්ලන්තය)',
        'nl_CW' => 'ලන්දේසි (කුරකාවෝ)',
        'nl_NL' => 'ලන්දේසි (නෙදර්ලන්තය)',
        'nl_SR' => 'ලන්දේසි (සුරිනාමය)',
        'nl_SX' => 'ලන්දේසි (ශාන්ත මාර්ටෙන්)',
        'nn' => 'නෝර්වීජියානු නයිනෝර්ස්ක්',
        'nn_NO' => 'නෝර්වීජියානු නයිනෝර්ස්ක් (නෝර්වේ)',
        'no' => 'නෝර්වීජියානු',
        'no_NO' => 'නෝර්වීජියානු (නෝර්වේ)',
        'om' => 'ඔරොමෝ',
        'om_ET' => 'ඔරොමෝ (ඉතියෝපියාව)',
        'om_KE' => 'ඔරොමෝ (කෙන්යාව)',
        'or' => 'ඔඩියා',
        'or_IN' => 'ඔඩියා (ඉන්දියාව)',
        'os' => 'ඔසිටෙක්',
        'os_GE' => 'ඔසිටෙක් (ජෝර්ජියාව)',
        'os_RU' => 'ඔසිටෙක් (රුසියාව)',
        'pa' => 'පන්ජාබි',
        'pa_Arab' => 'පන්ජාබි (අරාබි)',
        'pa_Arab_PK' => 'පන්ජාබි (අරාබි, පාකිස්තානය)',
        'pa_Guru' => 'පන්ජාබි (ගුර්මුඛි)',
        'pa_Guru_IN' => 'පන්ජාබි (ගුර්මුඛි, ඉන්දියාව)',
        'pa_IN' => 'පන්ජාබි (ඉන්දියාව)',
        'pa_PK' => 'පන්ජාබි (පාකිස්තානය)',
        'pl' => 'පෝලන්ත',
        'pl_PL' => 'පෝලන්ත (පෝලන්තය)',
        'ps' => 'පෂ්ටො',
        'ps_AF' => 'පෂ්ටො (ඇෆ්ගනිස්ථානය)',
        'ps_PK' => 'පෂ්ටො (පාකිස්තානය)',
        'pt' => 'පෘතුගීසි',
        'pt_AO' => 'පෘතුගීසි (ඇන්ගෝලාව)',
        'pt_BR' => 'පෘතුගීසි (බ්‍රසීලය)',
        'pt_CH' => 'පෘතුගීසි (ස්විස්ටර්ලන්තය)',
        'pt_CV' => 'පෘතුගීසි (කේප් වර්ඩ්)',
        'pt_GQ' => 'පෘතුගීසි (සමක ගිනියාව)',
        'pt_GW' => 'පෘතුගීසි (ගිනි බිසව්)',
        'pt_LU' => 'පෘතුගීසි (ලක්ශම්බර්ග්)',
        'pt_MO' => 'පෘතුගීසි (මැකාවු විශේෂ පරිපාලන කලාපය චීනය)',
        'pt_MZ' => 'පෘතුගීසි (මොසැම්බික්)',
        'pt_PT' => 'පෘතුගීසි (පෘතුගාලය)',
        'pt_ST' => 'පෘතුගීසි (සාඕ තෝම් සහ ප්‍රින්සිප්)',
        'pt_TL' => 'පෘතුගීසි (ටිමෝර් - ලෙස්ත්)',
        'qu' => 'ක්වීචුවා',
        'qu_BO' => 'ක්වීචුවා (බොලීවියාව)',
        'qu_EC' => 'ක්වීචුවා (ඉක්වදෝරය)',
        'qu_PE' => 'ක්වීචුවා (පේරු)',
        'rm' => 'රොමෑන්ශ්',
        'rm_CH' => 'රොමෑන්ශ් (ස්විස්ටර්ලන්තය)',
        'rn' => 'රුන්ඩි',
        'rn_BI' => 'රුන්ඩි (බුරුන්දි)',
        'ro' => 'රොමේනියානු',
        'ro_MD' => 'රොමේනියානු (මොල්ඩෝවාව)',
        'ro_RO' => 'රොමේනියානු (රුමේනියාව)',
        'ru' => 'රුසියානු',
        'ru_BY' => 'රුසියානු (බෙලරුස්)',
        'ru_KG' => 'රුසියානු (කිර්ගිස්තානය)',
        'ru_KZ' => 'රුසියානු (කසකස්තානය)',
        'ru_MD' => 'රුසියානු (මොල්ඩෝවාව)',
        'ru_RU' => 'රුසියානු (රුසියාව)',
        'ru_UA' => 'රුසියානු (යුක්රේනය)',
        'rw' => 'කින්යර්වන්ඩා',
        'rw_RW' => 'කින්යර්වන්ඩා (රුවන්ඩාව)',
        'sa' => 'සංස්කෘත',
        'sa_IN' => 'සංස්කෘත (ඉන්දියාව)',
        'sc' => 'සාර්ඩිනිඅන්',
        'sc_IT' => 'සාර්ඩිනිඅන් (ඉතාලිය)',
        'sd' => 'සින්ධි',
        'sd_Arab' => 'සින්ධි (අරාබි)',
        'sd_Arab_PK' => 'සින්ධි (අරාබි, පාකිස්තානය)',
        'sd_Deva' => 'සින්ධි (දේවනාගරී)',
        'sd_Deva_IN' => 'සින්ධි (දේවනාගරී, ඉන්දියාව)',
        'sd_IN' => 'සින්ධි (ඉන්දියාව)',
        'sd_PK' => 'සින්ධි (පාකිස්තානය)',
        'se' => 'උතුරු සාමි',
        'se_FI' => 'උතුරු සාමි (ෆින්ලන්තය)',
        'se_NO' => 'උතුරු සාමි (නෝර්වේ)',
        'se_SE' => 'උතුරු සාමි (ස්වීඩනය)',
        'sg' => 'සන්ග්‍රෝ',
        'sg_CF' => 'සන්ග්‍රෝ (මධ්‍යම අප්‍රිකානු ජනරජය)',
        'si' => 'සිංහල',
        'si_LK' => 'සිංහල (ශ්‍රී ලංකාව)',
        'sk' => 'ස්ලෝවැක්',
        'sk_SK' => 'ස්ලෝවැක් (ස්ලෝවැකියාව)',
        'sl' => 'ස්ලෝවේනියානු',
        'sl_SI' => 'ස්ලෝවේනියානු (ස්ලෝවේනියාව)',
        'sn' => 'ශෝනා',
        'sn_ZW' => 'ශෝනා (සිම්බාබ්වේ)',
        'so' => 'සෝමාලි',
        'so_DJ' => 'සෝමාලි (ජිබුටි)',
        'so_ET' => 'සෝමාලි (ඉතියෝපියාව)',
        'so_KE' => 'සෝමාලි (කෙන්යාව)',
        'so_SO' => 'සෝමාලි (සෝමාලියාව)',
        'sq' => 'ඇල්බේනියානු',
        'sq_AL' => 'ඇල්බේනියානු (ඇල්බේනියාව)',
        'sq_MK' => 'ඇල්බේනියානු (උතුරු මැසිඩෝනියාව)',
        'sr' => 'සර්බියානු',
        'sr_BA' => 'සර්බියානු (බොස්නියාව සහ හර්සගොවීනාව)',
        'sr_Cyrl' => 'සර්බියානු (සිරිලික්)',
        'sr_Cyrl_BA' => 'සර්බියානු (සිරිලික්, බොස්නියාව සහ හර්සගොවීනාව)',
        'sr_Cyrl_ME' => 'සර්බියානු (සිරිලික්, මොන්ටෙනීග්‍රෝ)',
        'sr_Cyrl_RS' => 'සර්බියානු (සිරිලික්, සර්බියාව)',
        'sr_Latn' => 'සර්බියානු (ලතින්)',
        'sr_Latn_BA' => 'සර්බියානු (ලතින්, බොස්නියාව සහ හර්සගොවීනාව)',
        'sr_Latn_ME' => 'සර්බියානු (ලතින්, මොන්ටෙනීග්‍රෝ)',
        'sr_Latn_RS' => 'සර්බියානු (ලතින්, සර්බියාව)',
        'sr_ME' => 'සර්බියානු (මොන්ටෙනීග්‍රෝ)',
        'sr_RS' => 'සර්බියානු (සර්බියාව)',
        'su' => 'සන්ඩනීසියානු',
        'su_ID' => 'සන්ඩනීසියානු (ඉන්දුනීසියාව)',
        'su_Latn' => 'සන්ඩනීසියානු (ලතින්)',
        'su_Latn_ID' => 'සන්ඩනීසියානු (ලතින්, ඉන්දුනීසියාව)',
        'sv' => 'ස්වීඩන්',
        'sv_AX' => 'ස්වීඩන් (ඕලන්ඩ් දූපත්)',
        'sv_FI' => 'ස්වීඩන් (ෆින්ලන්තය)',
        'sv_SE' => 'ස්වීඩන් (ස්වීඩනය)',
        'sw' => 'ස්වාහිලි',
        'sw_CD' => 'ස්වාහිලි (කොංගෝව [ඩීආර්සී])',
        'sw_KE' => 'ස්වාහිලි (කෙන්යාව)',
        'sw_TZ' => 'ස්වාහිලි (ටැන්සානියාව)',
        'sw_UG' => 'ස්වාහිලි (උගන්ඩාව)',
        'ta' => 'දෙමළ',
        'ta_IN' => 'දෙමළ (ඉන්දියාව)',
        'ta_LK' => 'දෙමළ (ශ්‍රී ලංකාව)',
        'ta_MY' => 'දෙමළ (මැලේසියාව)',
        'ta_SG' => 'දෙමළ (සිංගප්පූරුව)',
        'te' => 'තෙළිඟු',
        'te_IN' => 'තෙළිඟු (ඉන්දියාව)',
        'tg' => 'ටජික්',
        'tg_TJ' => 'ටජික් (ටජිකිස්තානය)',
        'th' => 'තායි',
        'th_TH' => 'තායි (තායිලන්තය)',
        'ti' => 'ටිග්‍රින්යා',
        'ti_ER' => 'ටිග්‍රින්යා (එරිත්‍රියාව)',
        'ti_ET' => 'ටිග්‍රින්යා (ඉතියෝපියාව)',
        'tk' => 'ටර්ක්මෙන්',
        'tk_TM' => 'ටර්ක්මෙන් (ටර්ක්මෙනිස්ථානය)',
        'to' => 'ටොංගා',
        'to_TO' => 'ටොංගා (ටොංගා)',
        'tr' => 'තුර්කි',
        'tr_CY' => 'තුර්කි (සයිප්‍රසය)',
        'tr_TR' => 'තුර්කි (තුර්කිය)',
        'tt' => 'ටාටර්',
        'tt_RU' => 'ටාටර් (රුසියාව)',
        'ug' => 'උයිගර්',
        'ug_CN' => 'උයිගර් (චීනය)',
        'uk' => 'යුක්රේනියානු',
        'uk_UA' => 'යුක්රේනියානු (යුක්රේනය)',
        'ur' => 'උර්දු',
        'ur_IN' => 'උර්දු (ඉන්දියාව)',
        'ur_PK' => 'උර්දු (පාකිස්තානය)',
        'uz' => 'උස්බෙක්',
        'uz_AF' => 'උස්බෙක් (ඇෆ්ගනිස්ථානය)',
        'uz_Arab' => 'උස්බෙක් (අරාබි)',
        'uz_Arab_AF' => 'උස්බෙක් (අරාබි, ඇෆ්ගනිස්ථානය)',
        'uz_Cyrl' => 'උස්බෙක් (සිරිලික්)',
        'uz_Cyrl_UZ' => 'උස්බෙක් (සිරිලික්, උස්බෙකිස්ථානය)',
        'uz_Latn' => 'උස්බෙක් (ලතින්)',
        'uz_Latn_UZ' => 'උස්බෙක් (ලතින්, උස්බෙකිස්ථානය)',
        'uz_UZ' => 'උස්බෙක් (උස්බෙකිස්ථානය)',
        'vi' => 'වියට්නාම්',
        'vi_VN' => 'වියට්නාම් (වියට්නාමය)',
        'wo' => 'වොලොෆ්',
        'wo_SN' => 'වොලොෆ් (සෙනගාලය)',
        'xh' => 'ශෝසා',
        'xh_ZA' => 'ශෝසා (දකුණු අප්‍රිකාව)',
        'yi' => 'යිඩිශ්',
        'yi_001' => 'යිඩිශ් (ලෝකය)',
        'yo' => 'යොරූබා',
        'yo_BJ' => 'යොරූබා (බෙනින්)',
        'yo_NG' => 'යොරූබා (නයිජීරියාව)',
        'zh' => 'චීන',
        'zh_CN' => 'චීන (චීනය)',
        'zh_HK' => 'චීන (හොංකොං විශේෂ පරිපාලන කලාපය චීනය)',
        'zh_Hans' => 'චීන (සුළුකළ)',
        'zh_Hans_CN' => 'චීන (සුළුකළ, චීනය)',
        'zh_Hans_HK' => 'චීන (සුළුකළ, හොංකොං විශේෂ පරිපාලන කලාපය චීනය)',
        'zh_Hans_MO' => 'චීන (සුළුකළ, මැකාවු විශේෂ පරිපාලන කලාපය චීනය)',
        'zh_Hans_SG' => 'චීන (සුළුකළ, සිංගප්පූරුව)',
        'zh_Hant' => 'චීන (සාම්ප්‍රදායික)',
        'zh_Hant_HK' => 'චීන (සාම්ප්‍රදායික, හොංකොං විශේෂ පරිපාලන කලාපය චීනය)',
        'zh_Hant_MO' => 'චීන (සාම්ප්‍රදායික, මැකාවු විශේෂ පරිපාලන කලාපය චීනය)',
        'zh_Hant_TW' => 'චීන (සාම්ප්‍රදායික, තායිවානය)',
        'zh_MO' => 'චීන (මැකාවු විශේෂ පරිපාලන කලාපය චීනය)',
        'zh_SG' => 'චීන (සිංගප්පූරුව)',
        'zh_TW' => 'චීන (තායිවානය)',
        'zu' => 'සුලු',
        'zu_ZA' => 'සුලු (දකුණු අප්‍රිකාව)',
    ],
];
